import React from 'react';
import { IOptionProps, OptionLabelKey } from '../../../@types';
import { IOptionItemProps } from './AutocompleteItem';
export interface IAddAreaProps<T> {
    options: T[];
    searchText?: string;
}
export interface IAutocompleteListProps<T> extends Omit<IOptionItemProps<T>, 'option' | 'index'> {
    /**
     * Defines whether service could have more records to load via onLoadMore callback.
     */
    hasMore?: boolean;
    /**
     * Defines option's label key. key [field] to pick from object to display as label.
     */
    labelKey?: OptionLabelKey;
    /**
     * Defines loading state for new items.
     */
    loading?: boolean;
    /**
     * Defines loading label. Default is 'Loading...'
     */
    loadingLabel?: string;
    /**
     * Defines the maximum height of the container for scrolling
     */
    maxHeight?: string;
    /**
     * Defines load more records (infinite-scroll) callback.
     */
    onLoadMore?: () => void;
    /**
     * Defines the list items to be rendered
     */
    options: T[];
    /**
     * Defines the text for no option list item
     */
    noOptionText?: string;
    /**
     * Defines the add area when auto complete item not found
     */
    renderAddArea?: (props: IAddAreaProps<T>) => React.ReactNode;
    /**
     * Defines the list option component
     */
    renderOptionLabel?: (props: any) => React.ReactNode;
    /**
     * Defines the search text value
     */
    searchText?: string;
    /**
     * Defines avatar visibility in each option
     */
    showAvatar?: boolean;
    /**
     * Defines the stack order of element
     */
    zIndex?: string;
}
export declare function AutocompleteList<T extends IOptionProps>({ className, getItemProps, hasMore, highlightedIndex, iconType, labelKey, loading, loadingLabel, maxHeight, noOptionText, onLoadMore, options, searchText, selected, showAvatar, renderAddArea, zIndex, renderOptionLabel, ...other }: IAutocompleteListProps<T>): JSX.Element;
//# sourceMappingURL=AutocompleteList.d.ts.map