import { ComponentPropsWithoutRef } from 'react';
import { ButtonSizes, Variant } from '../../../@types';
interface IButtonCommonProps extends ComponentPropsWithoutRef<'button'> {
    /**
     * Defines if the button is disabled
     */
    disabled?: boolean;
    /**
     * Defines the focus offset color between button and ring
     */
    focusOffsetColor?: string;
    /**
     * Defines the icon style
     */
    iconClass?: string;
}
export declare type IButtonConditionalProps = 
/**
 * Icon only button
 */
{
    /**
     * Defines the background & text color of the button
     */
    variant?: keyof typeof Variant;
    /**
     * Defines icon only button
     */
    isOnlyIcon: true | false;
    /**
     * Defines the dimensions of the icon button for all variants
     */
    size?: keyof typeof ButtonSizes;
    /**
     * Defines icon type
     */
    iconType?: string;
}
/**
 * Regular button
 */
 | {
    /**
     * Defines icon only button
     */
    isOnlyIcon?: never;
    /**
     * Defines the background & text color of the button
     */
    variant?: keyof typeof Variant;
    /**
     * You can only set 'size' for regular button as 'lg' or 'xl'. 'size' by default 'lg'
     */
    size?: Exclude<keyof typeof ButtonSizes, 'sm'>;
    /**
     * You can not define 'isOnlyIcon' with regular button
     */
    iconType?: string;
};
export declare type IButtonProps = IButtonCommonProps & IButtonConditionalProps;
export {};
//# sourceMappingURL=types.d.ts.map